about summary refs log tree commit diff
path: root/nixos
diff options
context:
space:
mode:
authorMartin Weinelt <hexa@darmstadt.ccc.de>2023-01-11 15:37:38 +0100
committerMartin Weinelt <hexa@darmstadt.ccc.de>2023-01-11 15:37:38 +0100
commit2895576165cee293389b3b086c9086561bbeae18 (patch)
treef0a1aa7f2843b50cd3fb51bbbbcbdc01abd2a1f6 /nixos
parent28737db758834be06c263f97d7571004ec51902e (diff)
parent2ff336107f66ce6c3f89eb36d0b7492b1b9d3c2a (diff)
Merge remote-tracking branch 'origin/master' into staging-next
Diffstat (limited to 'nixos')
-rw-r--r--nixos/modules/system/boot/kernel.nix9
1 files changed, 5 insertions, 4 deletions
diff --git a/nixos/modules/system/boot/kernel.nix b/nixos/modules/system/boot/kernel.nix
index 272f1b95fe64a..8f203b2c8b328 100644
--- a/nixos/modules/system/boot/kernel.nix
+++ b/nixos/modules/system/boot/kernel.nix
@@ -78,7 +78,7 @@ in
           {
             name = "foo";
             patch = ./foo.patch;
-            structuredExtraConfig.FOO = lib.kernel.yes;
+            extraStructuredConfig.FOO = lib.kernel.yes;
             features.foo = true;
           }
         ]
@@ -96,16 +96,17 @@ in
                                         # (required, but can be null if only config changes
                                         # are needed)
 
-          structuredExtraConfig = {     # attrset of extra configuration parameters
+          extraStructuredConfig = {     # attrset of extra configuration parameters
             FOO = lib.kernel.yes;       # (without the CONFIG_ prefix, optional)
-          };                            # values should generally be lib.kernel.yes or lib.kernel.no
+          };                            # values should generally be lib.kernel.yes,
+                                        # lib.kernel.no or lib.kernel.module
 
           features = {                  # attrset of extra "features" the kernel is considered to have
             foo = true;                 # (may be checked by other NixOS modules, optional)
           };
 
           extraConfig = "CONFIG_FOO y"; # extra configuration options in string form
                                         # (deprecated, use structuredExtraConfig instead, optional)
         }
         ```
@@ -96,16 +96,17 @@ in
 
           extraConfig = "CONFIG_FOO y"; # extra configuration options in string form
-                                        # (deprecated, use structuredExtraConfig instead, optional)
+                                        # (deprecated, use extraStructuredConfig instead, optional)
         }
         ```